// original code from Apache Solr - ported to work with Lucene 3.x and reformatted to Search coding style
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.apache.solr.analysis;

import java.util.Map;

import org.apache.lucene.analysis.TokenStream;
import org.apache.lucene.analysis.shingle.ShingleFilter;

public class ShingleFilterFactory extends BaseTokenFilterFactory {
	private int maxShingleSize;
	private boolean outputUnigrams;

	public void init(Map<String, String> args) {
		super.init( args );
		maxShingleSize = getInt(
				"maxShingleSize",
				ShingleFilter.DEFAULT_MAX_SHINGLE_SIZE
		);
		outputUnigrams = getBoolean( "outputUnigrams", true );
	}

	public ShingleFilter create(TokenStream input) {
		ShingleFilter r = new ShingleFilter( input, maxShingleSize );
		r.setOutputUnigrams( outputUnigrams );
		return r;
	}
}

